"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const highlightjs_1 = __importDefault(require("highlightjs"));
const katex_1 = __importDefault(require("katex"));
const marked_1 = __importDefault(require("marked"));
const ipynb2html_core_1 = require("ipynb2html-core");
function highlight(code, lang) {
    return highlightjs_1.default.getLanguage(lang)
        ? highlightjs_1.default.highlight(lang, code, true).value
        : code;
}
const markdownRenderer = (markedOpts = {}, katexOpts = {}) => {
    if (highlightjs_1.default) { // highlightjs may be an optional dependency (in browser bundle)
        markedOpts = { highlight, ...markedOpts };
    }
    /**
     * Converts the given *markdown* into HTML.
     */
    return (markdown) => {
        const [text, math] = ipynb2html_core_1.mathExtractor.extractMath(markdown);
        const html = marked_1.default.parse(text, markedOpts);
        const mathHtml = math.map(({ value, displayMode }) => {
            return katex_1.default.renderToString(value, { ...katexOpts, displayMode });
        });
        return ipynb2html_core_1.mathExtractor.restoreMath(html, mathHtml);
    };
};
/**
 * Returns a pre-configured marked parser with math support (using KaTeX)
 * and code highlighter (highlight.js).
 *
 * @param {MarkedOptions} markedOpts Options for the marked Markdown renderer.
 * @param {KatexOptions} katexOpts Options for the KaTeX math renderer.
 */
exports.default = markdownRenderer;
//# sourceMappingURL=markdownRenderer.js.map